@@ -29,7 +29,9 @@ class DataCmd:
         self.item_file_path = config.get_item_file_path()
         self.supplier_file_path = config.get_supplier_file_path()
 
+        print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": Start loading data.")
         self.load_data_from_text_file(config)
+        print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": data loaded.")
 
         self.n_users = self.ratings.shape[0] if self.ratings is not None else self.train_data.shape[0]
         self.n_items = self.ratings.shape[1] if self.ratings is not None else self.train_data.shape[1]
@@ -98,7 +100,7 @@ class DataCmd:
 
         train_data = np.zeros((n_users, n_items))
         with open(train_path) as f:
-            for instance in f:
+            for instance in tqdm(f):
                 instance_separated = instance.strip().split(train_delimiter)
                 userid = instance_separated[0]
                 itemid = instance_separated[1]
@@ -110,10 +112,11 @@ class DataCmd:
                     self.itemid_mapped_data[itemid] = len(self.itemid_mapped_data)
 
                 train_data[self.userid_mapped_data[userid], self.itemid_mapped_data[itemid]] = rating
+        print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": train loaded.")
 
         test_data = np.zeros((n_users, n_items))
         with open(test_path) as f:
-            for instance in f:
+            for instance in tqdm(f):
                 instance_separated = instance.strip().split(test_delimiter)
                 userid = instance_separated[0]
                 itemid = instance_separated[1]
@@ -125,6 +128,7 @@ class DataCmd:
                     self.itemid_mapped_data[itemid] = len(self.itemid_mapped_data)
 
                 test_data[self.userid_mapped_data[userid], self.itemid_mapped_data[itemid]] = rating
+        print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": test loaded.")
         return train_data, test_data
     # def read_test_text_file(self, file_path, delimiter):
     #     data = np.zeros((self.train_data.shape))
@@ -181,12 +185,12 @@ class DataCmd:
         data = np.array(np.zeros((len(self.itemid_mapped_data.keys()), 1)))
         category_index = 0
         with open(file_path) as f:
-            for instance in f:
+            for instance in tqdm(f):
                 instance_separated = instance.strip().split(delimiter)
                 itemid = instance_separated[0]
                 categories = instance_separated[category_column].split(category_delimiter)
 
-                for category in categories:
+                for category in tqdm(categories):
                     # map categories, and update the dictionary
                     if category not in self.item_topic_mapped_data.keys():
                         self.item_topic_mapped_data[category] = category_index
@@ -241,12 +245,16 @@ class DataCmd:
         if config.get_splitter_model() == 'giventraintest':
             # self.train_data = self.read_rating_text_file(self.train_file_path, config.get_train_data_delimiter())
             # self.test_data = self.read_test_text_file(self.test_file_path, config.get_test_data_delimiter())
+            print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": Start loading train/test.")
             self.train_data, self.test_data = self.read_train_test_text_file(self.train_file_path, self.test_file_path, config.get_train_data_delimiter(), config.get_test_data_delimiter())
+            print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": train/test loaded.")
 
         if self.user_file_path is not None:
             self.user_data = self.read_user_text_file(self.user_file_path, config.get_user_data_delimiter())
         if self.item_file_path is not None:
+            print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": Start loading items.")
             self.item_data = self.read_item_text_file(self.item_file_path, config.get_item_data_delimiter(), config.get_item_data_category_column(), config.get_item_data_category_delimiter())
+            print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": Items loaded.")
         if self.supplier_file_path is not None:
             self.supplier_data = self.read_supplier_text_file(self.supplier_file_path, config.get_supplier_data_delimiter())
 
